Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1)

Unified Diff: generated/googleapis/lib/qpxexpress/v1.dart

Issue 1078053002: Roll of googleapis as of 4/7/2015. (Closed) Base URL: https://github.com/dart-lang/googleapis.git@master
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « generated/googleapis/lib/prediction/v1_6.dart ('k') | generated/googleapis/lib/reseller/v1.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: generated/googleapis/lib/qpxexpress/v1.dart
diff --git a/generated/googleapis/lib/qpxexpress/v1.dart b/generated/googleapis/lib/qpxexpress/v1.dart
index 040252bea031d53b951d7f300da2f245a8c3ac77..6de1e5dfccf51444933bb97cd68b4b79561d852c 100644
--- a/generated/googleapis/lib/qpxexpress/v1.dart
+++ b/generated/googleapis/lib/qpxexpress/v1.dart
@@ -1,17 +1,20 @@
+// This is a generated file (see the discoveryapis_generator project).
+
library googleapis.qpxExpress.v1;
-import "dart:core" as core;
-import "dart:collection" as collection;
-import "dart:async" as async;
-import "dart:convert" as convert;
+import 'dart:core' as core;
+import 'dart:collection' as collection;
+import 'dart:async' as async;
+import 'dart:convert' as convert;
-import "package:crypto/crypto.dart" as crypto;
+import 'package:_discoveryapis_commons/_discoveryapis_commons.dart' as commons;
+import 'package:crypto/crypto.dart' as crypto;
import 'package:http/http.dart' as http;
-import '../src/common_internal.dart' as common_internal;
-import '../common/common.dart' as common;
-export '../common/common.dart' show ApiRequestError;
-export '../common/common.dart' show DetailedApiRequestError;
+export 'package:_discoveryapis_commons/_discoveryapis_commons.dart' show
+ ApiRequestError, DetailedApiRequestError;
+
+const core.String USER_AGENT = 'dart-api-client qpxExpress/v1';
/**
* Lets you find the least expensive flights between an origin and a
@@ -19,20 +22,19 @@ export '../common/common.dart' show DetailedApiRequestError;
*/
class QpxExpressApi {
- final common_internal.ApiRequester _requester;
+ final commons.ApiRequester _requester;
TripsResourceApi get trips => new TripsResourceApi(_requester);
QpxExpressApi(http.Client client, {core.String rootUrl: "https://www.googleapis.com/", core.String servicePath: "qpxExpress/v1/trips/"}) :
- _requester = new common_internal.ApiRequester(client, rootUrl, servicePath);
+ _requester = new commons.ApiRequester(client, rootUrl, servicePath, USER_AGENT);
}
-/** Not documented yet. */
class TripsResourceApi {
- final common_internal.ApiRequester _requester;
+ final commons.ApiRequester _requester;
- TripsResourceApi(common_internal.ApiRequester client) :
+ TripsResourceApi(commons.ApiRequester client) :
_requester = client;
/**
@@ -44,7 +46,7 @@ class TripsResourceApi {
*
* Completes with a [TripsSearchResponse].
*
* Completes with a [common.ApiRequestError] if the API endpoint returned an
* error.
*
* If the used [http.Client] completes with an error when making a REST call,
@@ -55,7 +57,7 @@ class TripsResourceApi {
var _queryParams = new core.Map();
var _uploadMedia = null;
var _uploadOptions = null;
- var _downloadOptions = common.DownloadOptions.Metadata;
+ var _downloadOptions = commons.DownloadOptions.Metadata;
var _body = null;
if (request != null) {
@@ -447,7 +449,6 @@ class Data {
* character alphanumeric code used to identify a fare.)
*/
class FareInfo {
- /** Not documented yet. */
core.String basisCode;
/**
@@ -541,7 +542,6 @@ class FareInfo {
* change of aircraft between legs.
*/
class FlightInfo {
- /** Not documented yet. */
core.String carrier;
/** The flight number. */
@@ -1899,5 +1899,3 @@ class TripsSearchResponse {
return _json;
}
}
-
-
« no previous file with comments | « generated/googleapis/lib/prediction/v1_6.dart ('k') | generated/googleapis/lib/reseller/v1.dart » ('j') | no next file with comments »

Powered by Google App Engine
@@ -44,7 +46,7 @@ class TripsResourceApi {
* Completes with a [TripsSearchResponse].
*
- * Completes with a [common.ApiRequestError] if the API endpoint returned an
+ * Completes with a [commons.ApiRequestError] if the API endpoint returned an
* error.
*
This is Rietveld 408576698